# This file was auto-generated by Fern from our API Definition.

import typing

UsageGetCharactersUsageMetricsRequestBreakdownType = typing.Union[
    typing.Literal["none", "voice", "user", "api_keys"], typing.Any
]
