# This file was auto-generated by Fern from our API Definition.

import typing
from ...types.initialize_connection import InitializeConnection
from ...types.send_text import SendText
from ...types.close_connection import CloseConnection

SendMessage = typing.Union[InitializeConnection, SendText, CloseConnection]
