# This file was auto-generated by Fern from our API Definition.

from .types import BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole

__all__ = ["BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole"]
