# This file was auto-generated by Fern from our API Definition.

import typing

BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole = typing.Union[
    typing.Literal["workspace_admin", "workspace_member"], typing.Any
]
