# This file was auto-generated by Fern from our API Definition.

from .types import GetTranscriptForDubV1DubbingDubbingIdTranscriptLanguageCodeGetRequestFormatType

__all__ = ["GetTranscriptForDubV1DubbingDubbingIdTranscriptLanguageCodeGetRequestFormatType"]
