# This file was auto-generated by Fern from our API Definition.

import enum


class ElevenLabsEnvironment(enum.Enum):
    PRODUCTION = "https://api.elevenlabs.io"
    PRODUCTION_US = "https://api.us.elevenlabs.io"
